# -*- coding: utf-8 -*-
# moebel.py

from grafikfenster import *
from math import radians

from abc import ABC,abstractmethod # abstrakte Klasse realisieren
import platform
##versionsNummer=platform.python_version()[0]
    
class Moebel(ABC):
    """Klasse Moebel
    Oberklasse für das Zeichnen und Bearbeiten von
    Moebel-Symbolen fuer den Raumplaner"""

    def __init__(self,
                 xPos,
                 yPos,
                 breite,
                 tiefe,
                 winkel,
                 farbe,
                 sichtbar):
        """Konstruktor mit vordefinierten Parametern
        ist bei Moebel nicht sinnvoll"""
        self.x=xPos
        self.y=yPos
        self.b=breite
        self.t=tiefe
        self.w=winkel
        self.f=farbe
        self.s=sichtbar
        if sichtbar: self.Zeige()
        
    @abstractmethod
    def GibFigur(self):
        """Definiert den Pfad und transformiert ihn."""
        return NotImplemented

    def GibX(self):
        """Get-Methode fuer die x-Position"""
        return self.x
    
    def GibY(self):
        """Get-Methode fuer die y-Position"""
        return self.y
    
    def GibBreite(self):
        """Get-Methode fuer die Breite"""
        return self.b
    
    def GibTiefe(self):
        """Get-Methode fuer die Tiefe"""
        return self.t
    
    def GibWinkel(self):
        """Get-Methode fuer den Winkel"""
        return self.w
    
    def GibFarbe(self):
        """Get-Methode fuer die Farbe"""
        return self.f

    def GibSichtbar(self):
        """Get-Methode fuer die Sichtbarkeit"""
        return self.s

    def BewegeHorizontal(self, weite):
        """Veraendernde Methode fuer die x-Position"""
        self.Verberge()
        self.x += weite
        self.Zeige()
    
    def BewegeVertikal(self, weite):
        """Veraendernde Methode fuer die y-Position"""
        self.Verberge()
        self.y += weite
        self.Zeige()
    
    def Drehe(self, winkel):
        """Veraendernde Methode fuer die Orientierung [Winkel]"""
        self.Verberge()
        self.w += winkel
        self.Zeige()

    def AendereFarbe(self, neueFarbe):
        """Veraendernde Methode fuer die Farbe"""
        sichtbar=self.GibSichtbar()
        if sichtbar: self.Verberge()
        self.f = neueFarbe
        if sichtbar: self.Zeige()

    def Verberge(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert False"""
        self.s = False
        Zeichenflaeche.GibZeichenflaeche().Entferne(self)

    def Zeige(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert True"""
        self.s = True
        Zeichenflaeche.GibZeichenflaeche().Zeichne(self)

### ---------------------------------------------------
class MoebelApp(wx.App):
    """Test-Anwendung speziell fuer Stuhl"""
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        self.TestAnwendung()
        return True

    def TestAnwendung(self):
        """Allein fuer die Testanwendung.
        Sollte nicht gehen! """
        try:
            moebel = Moebel(30, 30, 40, 40, 270, 'blue', True)
        except Exception as e:
            print( str(e) )

        
### ---------------------------------------------------
if __name__ == '__main__':
    app = MoebelApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
